lakeview.GeneAnnotation
=======================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


.. automodule:: lakeview
   :members: GeneAnnotation
   :noindex:

.. automodule:: lakeview.annotation
   :members: AnnotationRecord

